@@ -879,7 +879,7 @@ class Grid:
                    node,
                    delta_x,
                    delta_y,
-                   allow_shifting_node_outside_boundary=False):
+                   allow_shifting_node_outside_boundary=True):
         """
         This method increment the 'pixel_x_axis' value by delta_x and the
         'pixel_y_axis' value by delta_y for the node given as parameter.
@@ -905,7 +905,7 @@ class Grid:
             delta_x <= self.__image.shape[0]
             and self.__nodes['pixel_x_axis'][node] + delta_x >= 0
             and self.__nodes[
-                'pixel_y_axis'][node] + delta_y <= self.__image.shape[1]
+                'pixel_y_axis'][node] + delta_y <= self.get_image.shape[1]
             and self.__nodes[
                 'pixel_y_axis'][node] + delta_y >= 0)
 
